@@ -29,8 +29,8 @@ BASE_LASTFM = "http://ws.audioscrobbler.com/2.0/?method=album.getinfo"
 BASE_GOOGLE = "https://www.google.com/search?tbm=isch&q="
 GOOGLE_MEDIUM = "&tbs=isz:m"
 GOOGLE_SMALL = "&tbs=isz:s"
-GOOGLE_SQUARE = "&iar:s"
-GOOGLE_PHOTO = "&itp:photo"
+GOOGLE_SQUARE = "&tbs=iar:s"
+GOOGLE_PHOTO = "&tbs=itp:photo"
 
 CACHE_LOCATION = os.path.join (os.getenv ("HOME"), ".cache", "mussorgsky")
 # LastFM:
@@ -223,12 +223,12 @@ class MussorgskyAlbumArt:
         # 500 is just a safe limit
         for i in range (0, 500):
             # Iterate until find a jpeg
-            start = page.find ("imgurl=", starting_at)
+            start = page.find ("\"ou\":\"", starting_at)
             if (start == -1):
                 print "Can't find URL in results"
                 yield None
-            end = page.find ("&", start + len ("imgurl="))
-            current_option = page [start + len ("imgurl="): end].replace ("amp;", "")
+            end = page.find ("\",\"ow\":", start + len ("\"ou\":\""))
+            current_option = page [start + len ("\"ou\":\""): end].replace ("\",\"ow\":", "")
             if (current_option.lower().endswith (".jpg") or
                 current_option.lower().endswith (".jpeg")):
                 yield current_option
